<a id="mypy-boto3-mediaconvert"></a>

# mypy-boto3-mediaconvert

[![PyPI - mypy-boto3-mediaconvert](https://img.shields.io/pypi/v/mypy-boto3-mediaconvert.svg?color=blue)](https://pypi.org/project/mypy-boto3-mediaconvert)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-mediaconvert.svg?color=blue)](https://pypi.org/project/mypy-boto3-mediaconvert)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dw/mypy-boto3-mediaconvert?color=blue)](https://pypistats.org/packages/mypy-boto3-mediaconvert)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/master/logo.png)

Type annotations for
[boto3.MediaConvert 1.18.47](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/mediaconvert.html#MediaConvert)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-builder 5.3.1](https://github.com/vemel/mypy_boto3_builder).

More information can be found on
[boto3-stubs](https://pypi.org/project/boto3-stubs/) page and in
[mypy-boto3-mediaconvert docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediaconvert/)

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/master/demo.gif)

- [mypy-boto3-mediaconvert](#mypy-boto3-mediaconvert)
  - [How to install](#how-to-install)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Literals](#literals)
    - [Typed dictionaries](#typed-dictionaries)
  - [Versioning](#versioning)
  - [Documentation](#documentation)
  - [Support and contributing](#support-and-contributing)

<a id="how-to-install"></a>

## How to install

Install `boto3-stubs` for `MediaConvert` service.

```bash
python -m pip install boto3-stubs[mediaconvert]
```

<a id="usage"></a>

## Usage

<a id="vscode"></a>

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto-stubs[mediaconvert]` in your environment:
  `python -m pip install 'boto3-stubs[mediaconvert]'`

Both type checking and auto-complete should work for `MediaConvert` service. No
explicit type annotations required, write your `boto3` code as usual.

<a id="pycharm"></a>

### PyCharm

- Install `boto-stubs[mediaconvert]` in your environment:
  `python -m pip install 'boto3-stubs[mediaconvert]'`

Both type checking and auto-complete should work for `MediaConvert` service. No
explicit type annotations required, write your `boto3` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed
`boto3-stubs` submodules.

<a id="other-ides"></a>

### Other IDEs

Not tested, but as long as your IDE supports `mypy` or `pyright`, everything
should work.

<a id="mypy"></a>

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `boto-stubs[mediaconvert]` in your environment:
  `python -m pip install 'boto3-stubs[mediaconvert]'`
- Run `mypy` as usual

Type checking should work for `MediaConvert` service. No explicit type
annotations required, write your `boto3` code as usual.

<a id="pyright"></a>

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `boto-stubs[mediaconvert]` in your environment:
  `python -m pip install 'boto3-stubs[mediaconvert]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `MediaConvert` service. No explicit type
annotations required, write your `boto3` code as usual.

<a id="explicit-type-annotations"></a>

## Explicit type annotations

<a id="client-annotations"></a>

### Client annotations

`MediaConvertClient` provides annotations for `boto3.client("mediaconvert")`.

```python
import boto3

from mypy_boto3_mediaconvert import MediaConvertClient

client: MediaConvertClient = boto3.client("mediaconvert")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: MediaConvertClient = session.client("mediaconvert")
```

<a id="paginators-annotations"></a>

### Paginators annotations

`mypy_boto3_mediaconvert.paginator` module contains type annotations for all
paginators.

```python
from mypy_boto3_mediaconvert import MediaConvertClient
from mypy_boto3_mediaconvert.paginator import (
    DescribeEndpointsPaginator,
    ListJobTemplatesPaginator,
    ListJobsPaginator,
    ListPresetsPaginator,
    ListQueuesPaginator,
)

client: MediaConvertClient = boto3.client("mediaconvert")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
describe_endpoints_paginator: DescribeEndpointsPaginator = client.get_paginator("describe_endpoints")
list_job_templates_paginator: ListJobTemplatesPaginator = client.get_paginator("list_job_templates")
list_jobs_paginator: ListJobsPaginator = client.get_paginator("list_jobs")
list_presets_paginator: ListPresetsPaginator = client.get_paginator("list_presets")
list_queues_paginator: ListQueuesPaginator = client.get_paginator("list_queues")
```

<a id="literals"></a>

### Literals

`mypy_boto3_mediaconvert.literals` module contains literals extracted from
shapes that can be used in user code for type checking.

```python
from mypy_boto3_mediaconvert.literals import (
    AacAudioDescriptionBroadcasterMixType,
    AacCodecProfileType,
    AacCodingModeType,
    AacRateControlModeType,
    AacRawFormatType,
    AacSpecificationType,
    AacVbrQualityType,
    Ac3BitstreamModeType,
    Ac3CodingModeType,
    Ac3DynamicRangeCompressionLineType,
    Ac3DynamicRangeCompressionProfileType,
    Ac3DynamicRangeCompressionRfType,
    Ac3LfeFilterType,
    Ac3MetadataControlType,
    AccelerationModeType,
    AccelerationStatusType,
    AfdSignalingType,
    AlphaBehaviorType,
    AncillaryConvert608To708Type,
    AncillaryTerminateCaptionsType,
    AntiAliasType,
    AudioChannelTagType,
    AudioCodecType,
    AudioDefaultSelectionType,
    AudioLanguageCodeControlType,
    AudioNormalizationAlgorithmControlType,
    AudioNormalizationAlgorithmType,
    AudioNormalizationLoudnessLoggingType,
    AudioNormalizationPeakCalculationType,
    AudioSelectorTypeType,
    AudioTypeControlType,
    Av1AdaptiveQuantizationType,
    Av1FramerateControlType,
    Av1FramerateConversionAlgorithmType,
    Av1RateControlModeType,
    Av1SpatialAdaptiveQuantizationType,
    AvcIntraClassType,
    AvcIntraFramerateControlType,
    AvcIntraFramerateConversionAlgorithmType,
    AvcIntraInterlaceModeType,
    AvcIntraScanTypeConversionModeType,
    AvcIntraSlowPalType,
    AvcIntraTelecineType,
    AvcIntraUhdQualityTuningLevelType,
    BillingTagsSourceType,
    BurnInSubtitleStylePassthroughType,
    BurninSubtitleAlignmentType,
    BurninSubtitleApplyFontColorType,
    BurninSubtitleBackgroundColorType,
    BurninSubtitleFallbackFontType,
    BurninSubtitleFontColorType,
    BurninSubtitleOutlineColorType,
    BurninSubtitleShadowColorType,
    BurninSubtitleTeletextSpacingType,
    CaptionDestinationTypeType,
    CaptionSourceTypeType,
    CmafClientCacheType,
    CmafCodecSpecificationType,
    CmafEncryptionTypeType,
    CmafImageBasedTrickPlayType,
    CmafInitializationVectorInManifestType,
    CmafIntervalCadenceType,
    CmafKeyProviderTypeType,
    CmafManifestCompressionType,
    CmafManifestDurationFormatType,
    CmafMpdProfileType,
    CmafPtsOffsetHandlingForBFramesType,
    CmafSegmentControlType,
    CmafSegmentLengthControlType,
    CmafStreamInfResolutionType,
    CmafTargetDurationCompatibilityModeType,
    CmafWriteDASHManifestType,
    CmafWriteHLSManifestType,
    CmafWriteSegmentTimelineInRepresentationType,
    CmfcAudioDurationType,
    CmfcAudioTrackTypeType,
    CmfcDescriptiveVideoServiceFlagType,
    CmfcIFrameOnlyManifestType,
    CmfcScte35EsamType,
    CmfcScte35SourceType,
    ColorMetadataType,
    ColorSpaceConversionType,
    ColorSpaceType,
    ColorSpaceUsageType,
    CommitmentType,
    ContainerTypeType,
    CopyProtectionActionType,
    DashIsoGroupAudioChannelConfigSchemeIdUriType,
    DashIsoHbbtvComplianceType,
    DashIsoImageBasedTrickPlayType,
    DashIsoIntervalCadenceType,
    DashIsoMpdProfileType,
    DashIsoPlaybackDeviceCompatibilityType,
    DashIsoPtsOffsetHandlingForBFramesType,
    DashIsoSegmentControlType,
    DashIsoSegmentLengthControlType,
    DashIsoWriteSegmentTimelineInRepresentationType,
    DecryptionModeType,
    DeinterlaceAlgorithmType,
    DeinterlacerControlType,
    DeinterlacerModeType,
    DescribeEndpointsModeType,
    DescribeEndpointsPaginatorName,
    DolbyVisionLevel6ModeType,
    DolbyVisionProfileType,
    DropFrameTimecodeType,
    DvbSubSubtitleFallbackFontType,
    DvbSubtitleAlignmentType,
    DvbSubtitleApplyFontColorType,
    DvbSubtitleBackgroundColorType,
    DvbSubtitleFontColorType,
    DvbSubtitleOutlineColorType,
    DvbSubtitleShadowColorType,
    DvbSubtitleStylePassthroughType,
    DvbSubtitleTeletextSpacingType,
    DvbSubtitlingTypeType,
    DvbddsHandlingType,
    Eac3AtmosBitstreamModeType,
    Eac3AtmosCodingModeType,
    Eac3AtmosDialogueIntelligenceType,
    Eac3AtmosDownmixControlType,
    Eac3AtmosDynamicRangeCompressionLineType,
    Eac3AtmosDynamicRangeCompressionRfType,
    Eac3AtmosDynamicRangeControlType,
    Eac3AtmosMeteringModeType,
    Eac3AtmosStereoDownmixType,
    Eac3AtmosSurroundExModeType,
    Eac3AttenuationControlType,
    Eac3BitstreamModeType,
    Eac3CodingModeType,
    Eac3DcFilterType,
    Eac3DynamicRangeCompressionLineType,
    Eac3DynamicRangeCompressionRfType,
    Eac3LfeControlType,
    Eac3LfeFilterType,
    Eac3MetadataControlType,
    Eac3PassthroughControlType,
    Eac3PhaseControlType,
    Eac3StereoDownmixType,
    Eac3SurroundExModeType,
    Eac3SurroundModeType,
    EmbeddedConvert608To708Type,
    EmbeddedTerminateCaptionsType,
    F4vMoovPlacementType,
    FileSourceConvert608To708Type,
    FontScriptType,
    H264AdaptiveQuantizationType,
    H264CodecLevelType,
    H264CodecProfileType,
    H264DynamicSubGopType,
    H264EntropyEncodingType,
    H264FieldEncodingType,
    H264FlickerAdaptiveQuantizationType,
    H264FramerateControlType,
    H264FramerateConversionAlgorithmType,
    H264GopBReferenceType,
    H264GopSizeUnitsType,
    H264InterlaceModeType,
    H264ParControlType,
    H264QualityTuningLevelType,
    H264RateControlModeType,
    H264RepeatPpsType,
    H264ScanTypeConversionModeType,
    H264SceneChangeDetectType,
    H264SlowPalType,
    H264SpatialAdaptiveQuantizationType,
    H264SyntaxType,
    H264TelecineType,
    H264TemporalAdaptiveQuantizationType,
    H264UnregisteredSeiTimecodeType,
    H265AdaptiveQuantizationType,
    H265AlternateTransferFunctionSeiType,
    H265CodecLevelType,
    H265CodecProfileType,
    H265DynamicSubGopType,
    H265FlickerAdaptiveQuantizationType,
    H265FramerateControlType,
    H265FramerateConversionAlgorithmType,
    H265GopBReferenceType,
    H265GopSizeUnitsType,
    H265InterlaceModeType,
    H265ParControlType,
    H265QualityTuningLevelType,
    H265RateControlModeType,
    H265SampleAdaptiveOffsetFilterModeType,
    H265ScanTypeConversionModeType,
    H265SceneChangeDetectType,
    H265SlowPalType,
    H265SpatialAdaptiveQuantizationType,
    H265TelecineType,
    H265TemporalAdaptiveQuantizationType,
    H265TemporalIdsType,
    H265TilesType,
    H265UnregisteredSeiTimecodeType,
    H265WriteMp4PackagingTypeType,
    HlsAdMarkersType,
    HlsAudioOnlyContainerType,
    HlsAudioOnlyHeaderType,
    HlsAudioTrackTypeType,
    HlsCaptionLanguageSettingType,
    HlsClientCacheType,
    HlsCodecSpecificationType,
    HlsDescriptiveVideoServiceFlagType,
    HlsDirectoryStructureType,
    HlsEncryptionTypeType,
    HlsIFrameOnlyManifestType,
    HlsImageBasedTrickPlayType,
    HlsInitializationVectorInManifestType,
    HlsIntervalCadenceType,
    HlsKeyProviderTypeType,
    HlsManifestCompressionType,
    HlsManifestDurationFormatType,
    HlsOfflineEncryptedType,
    HlsOutputSelectionType,
    HlsProgramDateTimeType,
    HlsSegmentControlType,
    HlsSegmentLengthControlType,
    HlsStreamInfResolutionType,
    HlsTargetDurationCompatibilityModeType,
    HlsTimedMetadataId3FrameType,
    ImscStylePassthroughType,
    InputDeblockFilterType,
    InputDenoiseFilterType,
    InputFilterEnableType,
    InputPsiControlType,
    InputRotateType,
    InputSampleRangeType,
    InputScanTypeType,
    InputTimecodeSourceType,
    JobPhaseType,
    JobStatusType,
    JobTemplateListByType,
    LanguageCodeType,
    ListJobTemplatesPaginatorName,
    ListJobsPaginatorName,
    ListPresetsPaginatorName,
    ListQueuesPaginatorName,
    M2tsAudioBufferModelType,
    M2tsAudioDurationType,
    M2tsBufferModelType,
    M2tsDataPtsControlType,
    M2tsEbpAudioIntervalType,
    M2tsEbpPlacementType,
    M2tsEsRateInPesType,
    M2tsForceTsVideoEbpOrderType,
    M2tsNielsenId3Type,
    M2tsPcrControlType,
    M2tsRateModeType,
    M2tsScte35SourceType,
    M2tsSegmentationMarkersType,
    M2tsSegmentationStyleType,
    M3u8AudioDurationType,
    M3u8DataPtsControlType,
    M3u8NielsenId3Type,
    M3u8PcrControlType,
    M3u8Scte35SourceType,
    MotionImageInsertionModeType,
    MotionImagePlaybackType,
    MovClapAtomType,
    MovCslgAtomType,
    MovMpeg2FourCCControlType,
    MovPaddingControlType,
    MovReferenceType,
    Mp3RateControlModeType,
    Mp4CslgAtomType,
    Mp4FreeSpaceBoxType,
    Mp4MoovPlacementType,
    MpdAccessibilityCaptionHintsType,
    MpdAudioDurationType,
    MpdCaptionContainerTypeType,
    MpdScte35EsamType,
    MpdScte35SourceType,
    Mpeg2AdaptiveQuantizationType,
    Mpeg2CodecLevelType,
    Mpeg2CodecProfileType,
    Mpeg2DynamicSubGopType,
    Mpeg2FramerateControlType,
    Mpeg2FramerateConversionAlgorithmType,
    Mpeg2GopSizeUnitsType,
    Mpeg2InterlaceModeType,
    Mpeg2IntraDcPrecisionType,
    Mpeg2ParControlType,
    Mpeg2QualityTuningLevelType,
    Mpeg2RateControlModeType,
    Mpeg2ScanTypeConversionModeType,
    Mpeg2SceneChangeDetectType,
    Mpeg2SlowPalType,
    Mpeg2SpatialAdaptiveQuantizationType,
    Mpeg2SyntaxType,
    Mpeg2TelecineType,
    Mpeg2TemporalAdaptiveQuantizationType,
    MsSmoothAudioDeduplicationType,
    MsSmoothFragmentLengthControlType,
    MsSmoothManifestEncodingType,
    MxfAfdSignalingType,
    MxfProfileType,
    MxfXavcDurationModeType,
    NielsenActiveWatermarkProcessTypeType,
    NielsenSourceWatermarkStatusTypeType,
    NielsenUniqueTicPerAudioTrackTypeType,
    NoiseFilterPostTemporalSharpeningType,
    NoiseReducerFilterType,
    OrderType,
    OutputGroupTypeType,
    OutputSdtType,
    PresetListByType,
    PricingPlanType,
    ProresChromaSamplingType,
    ProresCodecProfileType,
    ProresFramerateControlType,
    ProresFramerateConversionAlgorithmType,
    ProresInterlaceModeType,
    ProresParControlType,
    ProresScanTypeConversionModeType,
    ProresSlowPalType,
    ProresTelecineType,
    QueueListByType,
    QueueStatusType,
    RenewalTypeType,
    ReservationPlanStatusType,
    RespondToAfdType,
    S3ObjectCannedAclType,
    S3ServerSideEncryptionTypeType,
    SampleRangeConversionType,
    ScalingBehaviorType,
    SccDestinationFramerateType,
    SimulateReservedQueueType,
    SrtStylePassthroughType,
    StatusUpdateIntervalType,
    TeletextPageTypeType,
    TimecodeBurninPositionType,
    TimecodeSourceType,
    TimedMetadataType,
    TtmlStylePassthroughType,
    TypeType,
    Vc3ClassType,
    Vc3FramerateControlType,
    Vc3FramerateConversionAlgorithmType,
    Vc3InterlaceModeType,
    Vc3ScanTypeConversionModeType,
    Vc3SlowPalType,
    Vc3TelecineType,
    VchipActionType,
    VideoCodecType,
    VideoTimecodeInsertionType,
    Vp8FramerateControlType,
    Vp8FramerateConversionAlgorithmType,
    Vp8ParControlType,
    Vp8QualityTuningLevelType,
    Vp8RateControlModeType,
    Vp9FramerateControlType,
    Vp9FramerateConversionAlgorithmType,
    Vp9ParControlType,
    Vp9QualityTuningLevelType,
    Vp9RateControlModeType,
    WatermarkingStrengthType,
    WavFormatType,
    WebvttStylePassthroughType,
    Xavc4kIntraCbgProfileClassType,
    Xavc4kIntraVbrProfileClassType,
    Xavc4kProfileBitrateClassType,
    Xavc4kProfileCodecProfileType,
    Xavc4kProfileQualityTuningLevelType,
    XavcAdaptiveQuantizationType,
    XavcEntropyEncodingType,
    XavcFlickerAdaptiveQuantizationType,
    XavcFramerateControlType,
    XavcFramerateConversionAlgorithmType,
    XavcGopBReferenceType,
    XavcHdIntraCbgProfileClassType,
    XavcHdProfileBitrateClassType,
    XavcHdProfileQualityTuningLevelType,
    XavcHdProfileTelecineType,
    XavcInterlaceModeType,
    XavcProfileType,
    XavcSlowPalType,
    XavcSpatialAdaptiveQuantizationType,
    XavcTemporalAdaptiveQuantizationType,
    ServiceName,
)

def check_value(value: AacAudioDescriptionBroadcasterMixType) -> bool:
    ...
```

<a id="typed-dictionaries"></a>

### Typed dictionaries

`mypy_boto3_mediaconvert.type_defs` module contains structures and shapes
assembled to typed dictionaries for additional type checking.

```python
from mypy_boto3_mediaconvert.type_defs import (
    AacSettingsTypeDef,
    Ac3SettingsTypeDef,
    AccelerationSettingsTypeDef,
    AiffSettingsTypeDef,
    AncillarySourceSettingsTypeDef,
    AssociateCertificateRequestRequestTypeDef,
    AudioChannelTaggingSettingsTypeDef,
    AudioCodecSettingsTypeDef,
    AudioDescriptionTypeDef,
    AudioNormalizationSettingsTypeDef,
    AudioSelectorGroupTypeDef,
    AudioSelectorTypeDef,
    AutomatedAbrSettingsTypeDef,
    AutomatedEncodingSettingsTypeDef,
    Av1QvbrSettingsTypeDef,
    Av1SettingsTypeDef,
    AvailBlankingTypeDef,
    AvcIntraSettingsTypeDef,
    AvcIntraUhdSettingsTypeDef,
    BurninDestinationSettingsTypeDef,
    CancelJobRequestRequestTypeDef,
    CaptionDescriptionPresetTypeDef,
    CaptionDescriptionTypeDef,
    CaptionDestinationSettingsTypeDef,
    CaptionSelectorTypeDef,
    CaptionSourceFramerateTypeDef,
    CaptionSourceSettingsTypeDef,
    ChannelMappingTypeDef,
    CmafAdditionalManifestTypeDef,
    CmafEncryptionSettingsTypeDef,
    CmafGroupSettingsTypeDef,
    CmafImageBasedTrickPlaySettingsTypeDef,
    CmfcSettingsTypeDef,
    ColorCorrectorTypeDef,
    ContainerSettingsTypeDef,
    CreateJobRequestRequestTypeDef,
    CreateJobResponseTypeDef,
    CreateJobTemplateRequestRequestTypeDef,
    CreateJobTemplateResponseTypeDef,
    CreatePresetRequestRequestTypeDef,
    CreatePresetResponseTypeDef,
    CreateQueueRequestRequestTypeDef,
    CreateQueueResponseTypeDef,
    DashAdditionalManifestTypeDef,
    DashIsoEncryptionSettingsTypeDef,
    DashIsoGroupSettingsTypeDef,
    DashIsoImageBasedTrickPlaySettingsTypeDef,
    DeinterlacerTypeDef,
    DeleteJobTemplateRequestRequestTypeDef,
    DeletePresetRequestRequestTypeDef,
    DeleteQueueRequestRequestTypeDef,
    DescribeEndpointsRequestRequestTypeDef,
    DescribeEndpointsResponseTypeDef,
    DestinationSettingsTypeDef,
    DisassociateCertificateRequestRequestTypeDef,
    DolbyVisionLevel6MetadataTypeDef,
    DolbyVisionTypeDef,
    DvbNitSettingsTypeDef,
    DvbSdtSettingsTypeDef,
    DvbSubDestinationSettingsTypeDef,
    DvbSubSourceSettingsTypeDef,
    DvbTdtSettingsTypeDef,
    Eac3AtmosSettingsTypeDef,
    Eac3SettingsTypeDef,
    EmbeddedDestinationSettingsTypeDef,
    EmbeddedSourceSettingsTypeDef,
    EndpointTypeDef,
    EsamManifestConfirmConditionNotificationTypeDef,
    EsamSettingsTypeDef,
    EsamSignalProcessingNotificationTypeDef,
    ExtendedDataServicesTypeDef,
    F4vSettingsTypeDef,
    FileGroupSettingsTypeDef,
    FileSourceSettingsTypeDef,
    FrameCaptureSettingsTypeDef,
    GetJobRequestRequestTypeDef,
    GetJobResponseTypeDef,
    GetJobTemplateRequestRequestTypeDef,
    GetJobTemplateResponseTypeDef,
    GetPresetRequestRequestTypeDef,
    GetPresetResponseTypeDef,
    GetQueueRequestRequestTypeDef,
    GetQueueResponseTypeDef,
    H264QvbrSettingsTypeDef,
    H264SettingsTypeDef,
    H265QvbrSettingsTypeDef,
    H265SettingsTypeDef,
    Hdr10MetadataTypeDef,
    Hdr10PlusTypeDef,
    HlsAdditionalManifestTypeDef,
    HlsCaptionLanguageMappingTypeDef,
    HlsEncryptionSettingsTypeDef,
    HlsGroupSettingsTypeDef,
    HlsImageBasedTrickPlaySettingsTypeDef,
    HlsRenditionGroupSettingsTypeDef,
    HlsSettingsTypeDef,
    HopDestinationTypeDef,
    Id3InsertionTypeDef,
    ImageInserterTypeDef,
    ImscDestinationSettingsTypeDef,
    InputClippingTypeDef,
    InputDecryptionSettingsTypeDef,
    InputTemplateTypeDef,
    InputTypeDef,
    InsertableImageTypeDef,
    JobMessagesTypeDef,
    JobSettingsTypeDef,
    JobTemplateSettingsTypeDef,
    JobTemplateTypeDef,
    JobTypeDef,
    KantarWatermarkSettingsTypeDef,
    ListJobTemplatesRequestRequestTypeDef,
    ListJobTemplatesResponseTypeDef,
    ListJobsRequestRequestTypeDef,
    ListJobsResponseTypeDef,
    ListPresetsRequestRequestTypeDef,
    ListPresetsResponseTypeDef,
    ListQueuesRequestRequestTypeDef,
    ListQueuesResponseTypeDef,
    ListTagsForResourceRequestRequestTypeDef,
    ListTagsForResourceResponseTypeDef,
    M2tsScte35EsamTypeDef,
    M2tsSettingsTypeDef,
    M3u8SettingsTypeDef,
    MotionImageInserterTypeDef,
    MotionImageInsertionFramerateTypeDef,
    MotionImageInsertionOffsetTypeDef,
    MovSettingsTypeDef,
    Mp2SettingsTypeDef,
    Mp3SettingsTypeDef,
    Mp4SettingsTypeDef,
    MpdSettingsTypeDef,
    Mpeg2SettingsTypeDef,
    MsSmoothAdditionalManifestTypeDef,
    MsSmoothEncryptionSettingsTypeDef,
    MsSmoothGroupSettingsTypeDef,
    MxfSettingsTypeDef,
    MxfXavcProfileSettingsTypeDef,
    NexGuardFileMarkerSettingsTypeDef,
    NielsenConfigurationTypeDef,
    NielsenNonLinearWatermarkSettingsTypeDef,
    NoiseReducerFilterSettingsTypeDef,
    NoiseReducerSpatialFilterSettingsTypeDef,
    NoiseReducerTemporalFilterSettingsTypeDef,
    NoiseReducerTypeDef,
    OpusSettingsTypeDef,
    OutputChannelMappingTypeDef,
    OutputDetailTypeDef,
    OutputGroupDetailTypeDef,
    OutputGroupSettingsTypeDef,
    OutputGroupTypeDef,
    OutputSettingsTypeDef,
    OutputTypeDef,
    PaginatorConfigTypeDef,
    PartnerWatermarkingTypeDef,
    PresetSettingsTypeDef,
    PresetTypeDef,
    ProresSettingsTypeDef,
    QueueTransitionTypeDef,
    QueueTypeDef,
    RectangleTypeDef,
    RemixSettingsTypeDef,
    ReservationPlanSettingsTypeDef,
    ReservationPlanTypeDef,
    ResourceTagsTypeDef,
    ResponseMetadataTypeDef,
    S3DestinationAccessControlTypeDef,
    S3DestinationSettingsTypeDef,
    S3EncryptionSettingsTypeDef,
    SccDestinationSettingsTypeDef,
    SpekeKeyProviderCmafTypeDef,
    SpekeKeyProviderTypeDef,
    SrtDestinationSettingsTypeDef,
    StaticKeyProviderTypeDef,
    TagResourceRequestRequestTypeDef,
    TeletextDestinationSettingsTypeDef,
    TeletextSourceSettingsTypeDef,
    TimecodeBurninTypeDef,
    TimecodeConfigTypeDef,
    TimedMetadataInsertionTypeDef,
    TimingTypeDef,
    TrackSourceSettingsTypeDef,
    TtmlDestinationSettingsTypeDef,
    UntagResourceRequestRequestTypeDef,
    UpdateJobTemplateRequestRequestTypeDef,
    UpdateJobTemplateResponseTypeDef,
    UpdatePresetRequestRequestTypeDef,
    UpdatePresetResponseTypeDef,
    UpdateQueueRequestRequestTypeDef,
    UpdateQueueResponseTypeDef,
    Vc3SettingsTypeDef,
    VideoCodecSettingsTypeDef,
    VideoDescriptionTypeDef,
    VideoDetailTypeDef,
    VideoPreprocessorTypeDef,
    VideoSelectorTypeDef,
    VorbisSettingsTypeDef,
    Vp8SettingsTypeDef,
    Vp9SettingsTypeDef,
    WavSettingsTypeDef,
    WebvttDestinationSettingsTypeDef,
    WebvttHlsSourceSettingsTypeDef,
    Xavc4kIntraCbgProfileSettingsTypeDef,
    Xavc4kIntraVbrProfileSettingsTypeDef,
    Xavc4kProfileSettingsTypeDef,
    XavcHdIntraCbgProfileSettingsTypeDef,
    XavcHdProfileSettingsTypeDef,
    XavcSettingsTypeDef,
)

def get_structure() -> AacSettingsTypeDef:
    return {
      ...
    }
```

<a id="versioning"></a>

## Versioning

`mypy-boto3-mediaconvert` version is the same as related `boto3` version and
follows [PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

<a id="documentation"></a>

## Documentation

All type annotations can be found in
[mypy-boto3-mediaconvert docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediaconvert/)

<a id="support-and-contributing"></a>

## Support and contributing

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/vemel/mypy_boto3_builder/issues/)
repository.
